@@ -18,7 +18,7 @@
 /* #undef LINK_POLLY_INTO_TOOLS */
 
 /* Target triple LLVM will generate code for by default */
-#define LLVM_DEFAULT_TARGET_TRIPLE "mips64-unknown-openbsd6.1"
+#define LLVM_DEFAULT_TARGET_TRIPLE "arm-unknown-openbsd6.2"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -27,28 +27,28 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "mips64-unknown-openbsd6.1"
+#define LLVM_HOST_TRIPLE "arm-unknown-openbsd6.2"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH Mips
+#define LLVM_NATIVE_ARCH ARM
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeARMAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeARMAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeARMDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeARMTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeARMTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeARMTargetMC
 
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
@@ -56,9 +56,6 @@
 /* Define if this is Win32ish platform */
 /* #undef LLVM_ON_WIN32 */
 
-/* Installation prefix directory */
-#define LLVM_PREFIX "/usr/local"
-
 /* Define if we have the Intel JIT API runtime support library */
 #define LLVM_USE_INTEL_JITEVENTS 0
 
@@ -66,7 +63,7 @@
 #define LLVM_USE_OPROFILE 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 4
+#define LLVM_VERSION_MAJOR 5
 
 /* Minor version of the LLVM API */
 #define LLVM_VERSION_MINOR 0
@@ -75,6 +72,6 @@
 #define LLVM_VERSION_PATCH 0
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "4.0.0"
+#define LLVM_VERSION_STRING "5.0.0"
 
 #endif
